import { StandaloneServices, IConfigurationService } from 'vscode/services';
import { configurationRegistry } from 'vscode/service-override/configuration';

configurationRegistry.registerDefaultConfigurations([{
  overrides: {
    'editor.codeLens': false,
    'editor.fontSize': 12,
    'editor.maxTokenizationLineLength': 1000,
    'editor.quickSuggestions': false,
    'files.eol': '\n',
    'editor.semanticTokenColorCustomizations': {
      rules: {
        '*.static': {
          fontStyle: 'italic'
        },
        '*.final.static': {
          fontStyle: 'italic bold'
        },
        '*.readonly': {
          fontStyle: 'bold'
        },
        '*.deprecated': {
          fontStyle: 'strikethrough'
        }
      }
    }
  }
}]);
function onConfigurationChanged(listener) {
  const configurationService = StandaloneServices.get(IConfigurationService);
  return configurationService.onDidChangeConfiguration(listener);
}
function getConfiguration(language) {
  let section = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'editor';
  const configurationService = StandaloneServices.get(IConfigurationService);
  return configurationService.getValue(section, {
    overrideIdentifier: language
  });
}
function registerConfigurations(configurations, validate) {
  configurationRegistry.registerConfigurations(configurations, validate);
}
function registerDefaultConfigurations(defaultConfigurations) {
  configurationRegistry.registerDefaultConfigurations(defaultConfigurations.map(overrides => ({
    overrides
  })));
}

export { registerDefaultConfigurations as a, getConfiguration as g, onConfigurationChanged as o, registerConfigurations as r };
